@@ -1,22 +1,9 @@
 /*
-    This file is part of kdev-python, the python language plugin for KDevelop
-    Copyright (C) 2012  Sven Brauch <svenbrauch@googlemail.com>
+    SPDX-FileCopyrightText: 2012 Sven Brauch <svenbrauch@googlemail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include <QTimer>
 #include <QApplication>
 
@@ -494,10 +481,22 @@ void DebugSession::stopDebugger()
     if ( ! m_debuggerProcess->waitForFinished(200) ) {
         m_debuggerProcess->kill();
     }
+    qCDebug(KDEV_PYTHON_DEBUGGER) << "stopped debugger";
+    finalizeState();
+}
+
+void DebugSession::killDebuggerNow()
+{
+    qCDebug(KDEV_PYTHON_DEBUGGER) << "killing debugger now";
+    m_debuggerProcess->kill();
+    finalizeState();
+}
+
+void DebugSession::finalizeState()
+{
     m_commandQueue.clear();
     m_nextNotifyMethod = nullptr;
     m_nextNotifyObject.clear();
-    qCDebug(KDEV_PYTHON_DEBUGGER) << "killed debugger";
     setState(IDebugSession::EndedState);
 }
 
@@ -524,3 +523,4 @@ KDevelop::IDebugSession::DebuggerState DebugSession::state() const
 
 }
 
+#include "moc_debugsession.cpp"
