@@ -1,20 +1,8 @@
 /*
-   Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
-   Copyright 2008 Niko Sams <niko.sams@gmail.com>
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2008 Niko Sams <niko.sams@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "declarationnavigationcontext.h"
@@ -50,11 +38,11 @@ QString DeclarationNavigationContext::getLink(const QString& name, DeclarationPo
 
 void DeclarationNavigationContext::htmlClass()
 {
-    StructureType::Ptr klass = declaration()->abstractType().cast<StructureType>();
-    Q_ASSERT(klass);
+    Q_ASSERT(declaration()->abstractType());
+    auto klass = declaration()->abstractType().staticCast<StructureType>();
 
     modifyHtml() += QStringLiteral("class ");
-    eventuallyMakeTypeLinks( klass.cast<AbstractType>() );
+    eventuallyMakeTypeLinks( klass );
 
     auto classDecl = dynamic_cast<ClassDeclaration*>(klass->declaration(topContext().data()));
     if ( classDecl && classDecl->baseClassesSize() ) {
@@ -82,19 +70,19 @@ QString DeclarationNavigationContext::typeLinkOrString(const AbstractType::Ptr t
 void DeclarationNavigationContext::htmlIdentifiedType(AbstractType::Ptr type, const IdentifiedType* idType)
 {
     // TODO this code is duplicate of variablelengthcontainer::toString, resolve that somehow
-    if ( auto listType = type.cast<ListType>() ) {
+    if ( auto listType = type.dynamicCast<ListType>() ) {
         QString contentType;
         const QString containerType = getLink(listType->containerToString(),
                                               DeclarationPointer(idType->declaration(topContext().data())),
                                               NavigationAction::NavigateDeclaration );
-        if ( auto map = listType.cast<MapType>() ) {
+        if ( auto map = listType.dynamicCast<MapType>() ) {
             contentType.append(typeLinkOrString(map->keyType().abstractType()));
             contentType.append(" : ");
         }
         contentType.append(typeLinkOrString(listType->contentType().abstractType()));
         modifyHtml() += i18nc("as in list of int, set of string", "%1 of %2", containerType, contentType);
     }
-    else if (auto indexedContainer = type.cast<IndexedContainer>()) {
+    else if (auto indexedContainer = type.dynamicCast<IndexedContainer>()) {
         const QString containerType = getLink(indexedContainer->containerToString(),
                                               DeclarationPointer(idType->declaration(topContext().data())),
                                               NavigationAction::NavigateDeclaration );
@@ -121,3 +109,5 @@ void DeclarationNavigationContext::eventuallyMakeTypeLinks(AbstractType::Ptr typ
 }
 
 }
+
+#include "moc_declarationnavigationcontext.cpp"
