@@ -1,22 +1,11 @@
-/*****************************************************************************
- * Copyright (c) 2007 Andreas Pakulat <apaku@gmx.de>                         *
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright (c) 2010-2013 Sven Brauch <svenbrauch@googlemail.com>           *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2010-2013 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
 #include "pythonparsejob.h"
 
 #include "pythondebug.h"
@@ -196,8 +185,9 @@ void ParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread* /*th
             // this prevents infinite loops in case something goes wrong (optimally, shouldn't reach here if
             // the document was already rescheduled, but there's many cases where this might still happen)
             if ( ! ( minimumFeatures() & Rescheduled ) && dependencyInQueue ) {
+                constexpr TopDUContext::Features features{TopDUContext::ForceUpdate};
                 KDevelop::ICore::self()->languageController()->backgroundParser()->addDocument(document(),
-                                     static_cast<TopDUContext::Features>(TopDUContext::ForceUpdate | Rescheduled), parsePriority(),
+                                     static_cast<TopDUContext::Features>(features | Rescheduled), parsePriority(),
                                      nullptr, ParseJob::FullSequentialProcessing);
             }
         }
@@ -293,4 +283,6 @@ void ParseJob::eventuallyDoPEP8Checking(TopDUContext* topContext)
 
 }
 
+#include "moc_pythonparsejob.cpp"
+
 // kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on; auto-insert-doxygen on
